# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RobotCreateV1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'expires_at': 'int',
        'access': 'list[Access]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'expires_at': 'expires_at',
        'access': 'access'
    }

    def __init__(self, name=None, description=None, expires_at=None, access=None, _configuration=None):  # noqa: E501
        """RobotCreateV1 - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._description = None
        self._expires_at = None
        self._access = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if expires_at is not None:
            self.expires_at = expires_at
        if access is not None:
            self.access = access

    @property
    def name(self):
        """Gets the name of this RobotCreateV1.  # noqa: E501

        The name of robot account  # noqa: E501

        :return: The name of this RobotCreateV1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RobotCreateV1.

        The name of robot account  # noqa: E501

        :param name: The name of this RobotCreateV1.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this RobotCreateV1.  # noqa: E501

        The description of robot account  # noqa: E501

        :return: The description of this RobotCreateV1.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RobotCreateV1.

        The description of robot account  # noqa: E501

        :param description: The description of this RobotCreateV1.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expires_at(self):
        """Gets the expires_at of this RobotCreateV1.  # noqa: E501

        The expiration time on or after which the JWT MUST NOT be accepted for processing.  # noqa: E501

        :return: The expires_at of this RobotCreateV1.  # noqa: E501
        :rtype: int
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this RobotCreateV1.

        The expiration time on or after which the JWT MUST NOT be accepted for processing.  # noqa: E501

        :param expires_at: The expires_at of this RobotCreateV1.  # noqa: E501
        :type: int
        """

        self._expires_at = expires_at

    @property
    def access(self):
        """Gets the access of this RobotCreateV1.  # noqa: E501

        The permission of robot account  # noqa: E501

        :return: The access of this RobotCreateV1.  # noqa: E501
        :rtype: list[Access]
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this RobotCreateV1.

        The permission of robot account  # noqa: E501

        :param access: The access of this RobotCreateV1.  # noqa: E501
        :type: list[Access]
        """

        self._access = access

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RobotCreateV1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RobotCreateV1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RobotCreateV1):
            return True

        return self.to_dict() != other.to_dict()
