# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProviderUnderProject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'provider': 'str',
        'enabled': 'bool',
        'default': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'provider': 'provider',
        'enabled': 'enabled',
        'default': 'default'
    }

    def __init__(self, id=None, provider=None, enabled=None, default=None, _configuration=None):  # noqa: E501
        """ProviderUnderProject - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._provider = None
        self._enabled = None
        self._default = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if provider is not None:
            self.provider = provider
        if enabled is not None:
            self.enabled = enabled
        if default is not None:
            self.default = default

    @property
    def id(self):
        """Gets the id of this ProviderUnderProject.  # noqa: E501


        :return: The id of this ProviderUnderProject.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProviderUnderProject.


        :param id: The id of this ProviderUnderProject.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def provider(self):
        """Gets the provider of this ProviderUnderProject.  # noqa: E501


        :return: The provider of this ProviderUnderProject.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this ProviderUnderProject.


        :param provider: The provider of this ProviderUnderProject.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def enabled(self):
        """Gets the enabled of this ProviderUnderProject.  # noqa: E501


        :return: The enabled of this ProviderUnderProject.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ProviderUnderProject.


        :param enabled: The enabled of this ProviderUnderProject.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def default(self):
        """Gets the default of this ProviderUnderProject.  # noqa: E501


        :return: The default of this ProviderUnderProject.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this ProviderUnderProject.


        :param default: The default of this ProviderUnderProject.  # noqa: E501
        :type: bool
        """

        self._default = default

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProviderUnderProject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProviderUnderProject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProviderUnderProject):
            return True

        return self.to_dict() != other.to_dict()
